# artifact-client
API for interacting with the Artifact Client.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.12
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import artifact_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import artifact_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import artifact_client
from artifact_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://xxny160gbe.execute-api.us-east-1.amazonaws.com/Prod
# See configuration.py for a list of all supported configuration parameters.
configuration = artifact_client.Configuration(
    host = "https://xxny160gbe.execute-api.us-east-1.amazonaws.com/Prod"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with artifact_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = artifact_client.DefaultApi(api_client)
    create_graph_request = artifact_client.CreateGraphRequest() # CreateGraphRequest | 

    try:
        # Create a new graph
        api_response = api_instance.create_graph(create_graph_request)
        print("The response of DefaultApi->create_graph:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->create_graph: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://xxny160gbe.execute-api.us-east-1.amazonaws.com/Prod*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**create_graph**](docs/DefaultApi.md#create_graph) | **POST** /graphs | Create a new graph
*DefaultApi* | [**delete_all_graphs**](docs/DefaultApi.md#delete_all_graphs) | **POST** /graphs/delete_all | Deletes all graphs
*DefaultApi* | [**delete_graph**](docs/DefaultApi.md#delete_graph) | **POST** /graphs/{graphId}/delete | Delete a graph
*DefaultApi* | [**get_graph_documents_meta**](docs/DefaultApi.md#get_graph_documents_meta) | **POST** /graphs/{graphId}/documents_meta | Get graph documents meta
*DefaultApi* | [**get_graph_stats**](docs/DefaultApi.md#get_graph_stats) | **POST** /graphs/{graphId}/stats | Get graph statistics
*DefaultApi* | [**ingest_document**](docs/DefaultApi.md#ingest_document) | **POST** /graphs/{graphId}/ingest | Ingest a document into a graph
*DefaultApi* | [**list_graphs**](docs/DefaultApi.md#list_graphs) | **GET** /graphs | List all graphs
*DefaultApi* | [**query_graph**](docs/DefaultApi.md#query_graph) | **POST** /graphs/{graphId}/query | Query a graph


## Documentation For Models

 - [CreateGraphRequest](docs/CreateGraphRequest.md)
 - [DocumentMeta](docs/DocumentMeta.md)
 - [Graph](docs/Graph.md)
 - [GraphStats](docs/GraphStats.md)
 - [IngestDocumentRequest](docs/IngestDocumentRequest.md)
 - [QueryRequest](docs/QueryRequest.md)
 - [QueryResult](docs/QueryResult.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




